@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
-/* @(#) $Header: /sources/code128php/code128php/code128barcode.class.php,v 1.2 2007/08/08 12:29:01 harding Exp $
+/* @(#) $Header: /sources/code128php/code128php/code128barcode.class.php,v 1.6 2007/11/10 13:34:19 harding Exp $
  *
  * code128barcode
  *
@@ -50,6 +50,8 @@ class code128barcode {
     var $checksum = 0;
     var $error_level = E_USER_WARNING;
     var $error = false;
+    var $unoptimized = false;
+    var $nozerofill = false;
     
     //
     // PRIVATE VARIABLES
@@ -313,8 +315,9 @@ class code128barcode {
                 $output_string .= $bar;
             }
 
+        if (!$this->nozerofill)
         // add quiet zone (10 x-dimensions)
-        $output_string = '0000000000' . $output_string . '0000000000';
+            $output_string = '0000000000' . $output_string . '0000000000';
         $this->output_string = $output_string;
         $this->_checksum = $this->_count = 0;
         $this->_barcode = array();
@@ -369,7 +372,13 @@ class code128barcode {
                 }
             
             $this->_actual_code = $this->_current_code;
-            if (($i + 3 < $limit) && preg_match('#[0-9]{4}#',$data[$i].$data[$i+1].$data[$i+2].$data[$i+3])) {
+            if ((($i + 3 < $limit)
+                        && preg_match('#[0-9]{4}#',
+                            $data[$i].$data[$i+1].$data[$i+2].$data[$i+3])) 
+                    or (($this->unoptimized) 
+                        && ($i + 1 < $limit)
+                        && preg_match('#[0-9]{2}#',
+                            $data[$i].$data[$i+1])))  {
                 $value = $data[$i].$data[$i+1];
                 $i++;
                 if (!$this->_current_code)
@@ -379,7 +388,14 @@ class code128barcode {
                         $this->specialchar('_CODEC');
                     $this->_actual_code = $this->_current_code = '_CODEC';
                     }
- 
+            
+            } elseif (($i + 1 < $limit) 
+                        && preg_match('#[0-9]{2}#',$data[$i].$data[$i+1])
+                        && $this->_current_code == '_CODEC') {
+                
+                $value = $data[$i].$data[$i+1];
+                $i++;
+
             } else {
                 if ($this->_current_code == '_CODEC') {
                     $this->specialchar('_CODEB');
