@@ -1,6 +1,6 @@
 <?php
 /* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
-/* @(#) $Header: /sources/code128php/code128php/example_fpdf.php,v 1.2 2007/08/08 12:29:01 harding Exp $
+/* @(#) $Header: /sources/code128php/code128php/example_fpdf.php,v 1.4 2007/11/10 11:31:28 harding Exp $
 
 /*
  * Example of use of code128barcode wirh fpdf
@@ -56,7 +56,7 @@ FIN;
 
         <p>prints code128 barcodes on labels sheets.</p>
         <div>This page uses 
-            <a href='../downloads/code128barcode/code128barcode.tgz'>
+            <a href='http://savannah.nongnu.org/projects/code128php'>
                 code128barcode.class.php</a><br>
                 (class and these examples provided in the tarball).<br />
             By Thomas Harding<br />
@@ -70,6 +70,10 @@ FIN;
                 $code = $barcode-&gt;output('code string');
                 ...
                 $code = $barcode-&gt;output('another code string');
+                $barcode-&gt;->nozerofill = true;
+                $code = $barcode-&gt;output('plain width barcode');
+                $barcode-&gt;unoptimized = true;
+                $code = $barcode-&gt;output('laposte colissimo 123456 barcode');
                 </pre>
            a very simple example with GD is 
            <a href='./example_png'>here</a>.
@@ -83,7 +87,7 @@ FIN;
             is disponible at
             <a href='http://www.nongnu.org/phpprintipp/'>www.nongnu.org</a>.
         </p>
-        <p>Code128 barcode specifications be founded
+        <p>Code128 barcode specifications be found
             <a href='http://www.adams1.com/pub/russadam/128code.html'>HERE</a>.
 <?php
     include ('./lib/cancel.inc');
@@ -122,7 +126,16 @@ FIN;
             <td>
                 {$values->printer_choice}
             </td>
-
+FIN;
+    $unoptimized = (!empty($values->unoptimized)) ? 'checked="checked"' : '';
+    $nozerofill = (!empty($values->nozerofill)) ? 'checked="checked"' : '';
+    echo <<<FIN
+            <th>
+                Colissimo <input type="checkbox" name="unoptimized" value="1" {$unoptimized} />
+            </th>
+            <th>
+                Plain width <input type="checkbox" name="nozerofill" value="1" {$nozerofill} />
+            </th>
 FIN;
 ?>
         </tr>
@@ -145,7 +158,6 @@ FIN;
     $margin_bottom = isset($values->margin_bottom) ? $values->margin_bottom : 5;
     $margin_left = isset($values->margin_left) ? $values->margin_left : 3;
     $margin_right = isset($values->margin_right) ? $values->margin_right : 3;
-    
     echo <<<FIN
         <tr>
             <td>
